# InlineResponse2002SoftwareEnvironments

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**cuda_version** | **str** | Cuda version. |
**environment_name** | **str** | Environment name. |
**environment_type** | **str** | Environment type. |
**image_name** | **str** | The name of the image. |
**image_sha** | **str** | The sha value of the image. |
**os_name** | **str** | The operating system name. |
**os_version** | **str** | Operating system version. |
**python_version** | **str** | Python version. |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
